@@ -166,7 +166,7 @@ def create_blueprint(
         response = send_file(
             file,
             download_name=Path(filename).name,
-            mimetype=mimetypes.guess_type(filename)[0],
+            mimetype="application/octet-stream",
         )
         return response
         # if config.cache_control:
